package Plugins::VolumeLock::Settings;

# VolumeLock copyright (c) 2004-2008 by Peter Watkins (peterw@tux.org)
#
# SqueezeCenter Copyright (c) 2001-2007 Logitech.
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 2.

use strict;
use base qw(Slim::Web::Settings);

use Slim::Utils::Prefs;
use Slim::Utils::DateTime;

my $prefs = preferences('plugin.VolumeLock');
my $serverPrefs = preferences('server');
my @prefNames = ('volumeLockMode');

sub needsClient {
	return 1;
}

$prefs->migrateClient(1, sub {
        my ($clientprefs, $client) = @_;
        # convert old pref
	my $oldPref = Slim::Utils::Prefs::OldPrefs->clientGet($client,'volumeLockVolume');
	$clientprefs->set('volume', $oldPref);
	if ( defined($oldPref) && ($oldPref =~ m/^[0-9]*$/) ) {
		$clientprefs->set('volumeLockMode', 'PLUGIN_VOLUME_FIX');
	}
	1;
});

sub name {
	if ( substr($::VERSION,0,3) lt 7.4 ) {
		return Slim::Web::HTTP::protectName('PLUGIN_VOLUME_LOCK_BASIC_SETTINGS');
	}
	return Slim::Web::HTTP::CSRF->protectName('PLUGIN_VOLUME_LOCK_BASIC_SETTINGS');
}

sub page {
	if ( substr($::VERSION,0,3) lt 7.4 ) {
		return Slim::Web::HTTP::protectURI('plugins/VolumeLock/settings/basic.html');
	}
	return Slim::Web::HTTP::CSRF->protectURI('plugins/VolumeLock/settings/basic.html');
}

sub prefs {
	my ($class,$client) = @_;
	return ($prefs->client($client), @prefNames );
}

sub handler {
	my ($class, $client, $params) = @_;
	### BUG - validate prefs!

	# for bug 6873/change 19155
	if ($::VERSION ge '7.1') {
		$params->{'pw'}->{'pref_prefix'} = 'pref_';
	} else {
		$params->{'pw'}->{'pref_prefix'} = '';
	}

	# save current volume if changing settings (needed for fixed & capped, no harm for allowing full range)
	if ( $params->{saveSettings} ) {
		$prefs->client($client)->set('volume',$serverPrefs->client($client)->get("volume"));
		$prefs->client($client)->set('volumeLockVolume',$serverPrefs->client($client)->get("volume"));
	}

	return $class->SUPER::handler($client, $params);
}

sub getPrefs {
	return $prefs;
}

1;

__END__
